# Disable Lua support on RHEL <= 7 because lua is not available.
# Disable Lua support on Fedora >= 23 because vera++ is not compatible with lua-5.3
%define enable_lua_support 1
%if (0%{?rhel} && 0%{?rhel} <= 7) && (0%{?fedora} < 23)
%define enable_lua_support 0
%endif

Name:           vera++
Version:        1.3.0
Release:        1%{?dist}
Summary:        A tool for verification, analysis and transformation of C++ source code

License:        Boost
URL:            https://bitbucket.org/verateam/vera
Source0:        %{url}/downloads/%{name}-%{version}.tar.gz

# Use LIB_SUFFIX to support 64-bit systems where native libraries are
# installed to /usr/lib64. See upstream pull request:
# http://bitbucket.org/verateam/vera/pull-request/6
Patch0:         0001-Append-LIB_SUFFIX-to-lib-install-destinations.patch

# Upstream pull request:
# http://bitbucket.org/verateam/vera/pull-request/7
Patch1:         0002-Prefer-the-newest-version-of-Lua-before-version-5.1-specifically.patch


%if (0%{?rhel} == 6)
BuildRequires:  cmake28 >= 2.8.6
%else
BuildRequires:  cmake >= 2.8.6
%endif
BuildRequires:  boost-devel
BuildRequires:  python-devel
BuildRequires:  tcl-devel
BuildRequires:  pandoc
%if %{enable_lua_support}
BuildRequires:  lua-devel
BuildRequires:  luabind-devel
%endif

%description
Vera++ is a programmable tool for verification, analysis and transformation of
C++ source code. Vera++ is mainly an engine that parses C++ source files and
presents the result of this parsing to scripts in the form of various
collections - the scripts are actually performing the requested tasks.


%package        devel
Summary:        A tool for verification, analysis and transformation of C++ source code
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains the files required to integrate %{name}
into a CMake build.


%prep
%setup -q
%patch0 -p1
%patch1 -p1


%build
mkdir build
pushd build

%if (0%{?rhel} == 6)
# On RHEL6: Use the newer cmake28 binary and workaround defective BoostConfig.cmake
%{cmake28} .. -DBoost_NO_BOOST_CMAKE=BOOL:ON \
%else
%{cmake} .. \
%endif
%if %{enable_lua_support}
  -DVERA_LUA:BOOL=ON \
%else
  -DVERA_LUA:BOOL=OFF \
%endif
  -DVERA_USE_SYSTEM_BOOST:BOOL=ON
make %{?_smp_mflags}

popd


%install
make -C build install DESTDIR=%{buildroot}


%clean
rm -rf %{buildroot}


%check
cd build
# Skip failing RuleDUMP test. See:
# https://bitbucket.org/verateam/vera/issue/73
# Skip failing (crashing) RuleL001.lua and RuleT019.lua unit tests on Fedora 23. See:
# https://bitbucket.org/verateam/vera/issue/74
%if (0%{?rhel} == 6)
ctest28 \
%else
#LD_PRELOAD=/usr/lib64/libSegFault.so
ctest \
%endif
  --output-on-failure \
%if 0%{?fedora} > 22
  --exclude-regex '^(.*\.lua|RuleDUMP)$'
%else
  --exclude-regex '^RuleDUMP$'
%endif


%files
%doc README.txt
%if (0%{?rhel} == 6)
%doc LICENSE_1_0.txt
%else
%license LICENSE_1_0.txt
%endif
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/profiles
%dir %{_libdir}/%{name}/transformations
%dir %{_libdir}/%{name}/rules
%{_libdir}/%{name}/profiles/*
%{_libdir}/%{name}/rules/*.tcl
%{_libdir}/%{name}/transformations/*.tcl
%{_datadir}/man/man1/%{name}.1*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/doc
%{_datadir}/%{name}/doc/%{name}.html

%files devel
%{_libdir}/%{name}/*.cmake
%{_libdir}/%{name}/*.cmake.in


%changelog
* Thu Apr  2 2015 Taylor Braun-Jones <taylor.braun-jones@ge.com> - 1.3.0-1
- Initial release.
